%define upstream_name    Iterator
%define upstream_version 0.03

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 11

Summary:    A general-purpose iterator class
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module//%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exception::Class)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::Simple)
BuildArch: noarch

%description
This module is meant to be the definitive implementation of iterators, as
popularized by Mark Jason Dominus's lectures and recent book (_Higher Order
Perl_, Morgan Kauffman, 2005).

An "iterator" is an object, represented as a code block that generates the
"next value" of a sequence, and generally implemented as a closure. When
you need a value to operate on, you pull it from the iterator. If it
depends on other iterators, it pulls values from them when it needs to.
Iterators can be chained together (see the Iterator::Util manpage for
functions that help you do just that), queueing up work to be done but _not
actually doing it_ until a value is needed at the front end of the chain.
At that time, one data value is pulled through the chain.

Contrast this with ordinary array processing, where you load or compute all
of the input values at once, then loop over them in memory. It's analogous
to the difference between looping over a file one line at a time, and
reading the entire file into an array of lines before operating on it.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.yml README
%{_mandir}/man3/*
%perl_vendorlib/*




%changelog
* Thu Jun 26 2025 umeabot <umeabot> 0.30.0-11.mga10
+ Revision: 2199530
- Mageia 10 Mass Rebuild

* Sun Mar 20 2022 umeabot <umeabot> 0.30.0-10.mga9
+ Revision: 1804154
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.30.0-9.mga8
+ Revision: 1495266
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.30.0-8.mga7
+ Revision: 1268851
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.30.0-7.mga6
+ Revision: 1028815
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.30.0-6.mga6
+ Revision: 944581
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.30.0-5.mga5
+ Revision: 745793
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.30.0-4.mga5
+ Revision: 685137
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.30.0-3.mga4
+ Revision: 512412
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.30.0-2.mga3
+ Revision: 368747
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 24 2011 kharec <kharec> 0.30.0-1.mga2
+ Revision: 171568
- imported package perl-Iterator


* Thu Nov 24 2011 cpan2dist 0.03-1mga
- initial mageia release, generated with cpan2dist
